DevelopSessionFactory class

Creates a fully-wired DevelopService with all its dependencies.

This factory consolidates the boilerplate of constructing test backends, device finders, and other CLI components so that both the CLI command runner and the MCP server can create a DevelopService without duplicating the wiring logic.

Constructors

DevelopSessionFactory()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create({required String projectRoot, required DisposeScope disposeScope, required Stream<List<int>> stdin, Future<void> onExit()?, void onTestsCompleted(TestCompletionResult result)?, void onLogEntry(Entry entry)?, bool verbose = false}) DevelopService
Creates all required CLI components and returns a DevelopService.