FlutterCommand class
Constructors
-
FlutterCommand(String executable, [List<
String> arguments = const []]) -
const
- FlutterCommand.parse(String command)
-
factory
Properties
-
arguments
→ List<
String> -
final
- executable → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited