DevelopOptions class
Configuration options for a patrol develop session.
This data class decouples the orchestration logic from CLI arg parsing, allowing both the CLI and MCP server to drive a develop session.
Constructors
-
DevelopOptions({required String target, required FlutterCommand flutterCommand, required BuildMode buildMode, required int testServerPort, required int appServerPort, String? flavor, String? appName, String? packageName, String? bundleId, String? buildName, String? buildNumber, List<
String> devices = const [], List<String> dartDefines = const [], List<String> dartDefineFromFilePaths = const [], bool generateBundle = true, bool uninstall = true, bool displayLabel = true, bool openDevtools = false, bool hideTestSteps = false, bool clearTestSteps = true, bool checkCompatibility = true, String? iosVersion}) -
const
- DevelopOptions.fromArgResults(ArgResults results, {required String target, FlutterCommand? flutterCommand})
-
factory
Properties
- appName → String?
-
final
- appServerPort → int
-
final
- buildMode → BuildMode
-
final
- buildName → String?
-
final
- buildNumber → String?
-
final
- bundleId → String?
-
final
- checkCompatibility → bool
-
final
- clearTestSteps → bool
-
final
-
dartDefineFromFilePaths
→ List<
String> -
Paths to dart define files from --dart-define-from-file.
final
-
dartDefines
→ List<
String> -
Custom dart defines from --dart-define args (key=value format).
final
-
devices
→ List<
String> -
Device names/ids to use. Empty means auto-select first device.
final
- displayLabel → bool
-
final
- flavor → String?
-
final
- flutterCommand → FlutterCommand
-
final
- generateBundle → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hideTestSteps → bool
-
final
- iosVersion → String?
-
iOS version for simulator. Defaults to 'latest' if null.
final
- openDevtools → bool
-
final
- packageName → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- target → String
-
final
- testServerPort → int
-
final
- uninstall → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parseArgs(
List< String> args, {required String target, FlutterCommand? flutterCommand}) → (DevelopOptions, ArgResults) -
Parses a list of CLI-style flag strings into DevelopOptions and the
full
ArgResults.